==> cmc_csci046_.data_structures-1.0.4.tar.gz: cmc_csci046_.data_structures-1.0.4/README.md <==

Build status:

[![tests-Fibonacci](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-fibonacci.yml/badge.svg)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-fibonacci.yml)
[![tests-Range](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-range.yml/badge.svg?branch=main)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-range.yml)
[![tests-Unicode](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-unicode.yml/badge.svg?branch=unicode)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-unicode.yml)
[![tests-BinaryTree](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-binarytree.yml/badge.svg)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-binarytree.yml)
[![tests-BST](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-BST.yml/badge.svg?branch=bst)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-BST.yml)
[![tests-AVLTree](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-avltree.yml/badge.svg?branch=avltree)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-avltree.yml)
[![tests-HeapTree](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-HeapTree.yml/badge.svg?branch=heap)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-HeapTree.yml)

This package was written as part of a homework assignment for CMC CSCI046: Data Structures and Algorithms. Use at your own risk!  

The package implements multiple types of data structures, including the following:   

- Generator objects (implemented with range and fibonacci)   
- Binary Trees    
- Binary Search Trees    
- AVL Trees    
- Heap Binary Trees

==> cmc_csci046_.data_structures-1.0.6.tar.gz: cmc_csci046_.data_structures-1.0.6/README.md <==

Build status:

![tests-Fibonacci](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-fibonacci.yml/badge.svg)

![tests-Range](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-range.yml)
[![tests-Unicode](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-unicode.yml/badge.svg?branch=unicode)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-unicode.yml)
[![tests-BinaryTree](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-binarytree.yml/badge.svg)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-binarytree.yml)
[![tests-BST](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-BST.yml/badge.svg?branch=bst)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-BST.yml)
[![tests-AVLTree](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-avltree.yml/badge.svg?branch=avltree)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-avltree.yml)
[![tests-HeapTree](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-HeapTree.yml/badge.svg?branch=heap)](https://github.com/Michaelhess17/containers-oop/actions/workflows/tests-HeapTree.yml)

This package was written as part of a homework assignment for CMC CSCI046: Data Structures and Algorithms. Use at your own risk!  

The package implements multiple types of data structures, including the following:   

- Generator objects (implemented with range and fibonacci)   
- Binary Trees    
- Binary Search Trees    
- AVL Trees    
- Heap Binary Trees
